paraphernalia package
=====================



Packages
--------
.. autosummary::

   paraphernalia.torch
.. toctree::
   :hidden:
   :maxdepth: 4

   paraphernalia.torch



Modules
-------
.. autosummary::

   paraphernalia.colors
   paraphernalia.glsl
   paraphernalia.jupyter
   paraphernalia.review
   paraphernalia.signature
   paraphernalia.utils
.. toctree::
   :hidden:
   :maxdepth: 4

   paraphernalia.colors
   paraphernalia.glsl
   paraphernalia.jupyter
   paraphernalia.review
   paraphernalia.signature
   paraphernalia.utils



Package contents
----------------
.. automodule:: paraphernalia
   :members:
   :undoc-members:
